% function computes the stiffness matrix of 2D trinagular element with linear approximation functions
% In:
%   xe - vector of x - nodal coordinates of the element (x1,x2,x3)
%   ye - vector of x - nodal coordinates of the element (y1,y2,y3)
%   E - Young's modulus
%   nu - Poisson's ratio
%
% Out:
%   ke - stiffness matrix of one element (6,6)
%   dbe - stress matrix (3,6)
%   de - material stiffness matrix (3,3)
%   be - matrix of the derivatives of shape functions (3,6)
%
function [ke,dbe,de,be] = plane_stress (xe,ye,E,nu)

Ae = area_triangle(xe,ye) ;

y23 = ye(2)-ye(3); y31 = ye(3)-ye(1); y12 = ye(1)-ye(2);
x32 = xe(3)-xe(2); x13 = xe(1)-xe(3); x21 = xe(2)-xe(1);

be = (1/(2*Ae))*[ y23, 0, y31, 0, y12, 0 ;
                  0, x32, 0, x13, 0, x21 ;
                  x32,y23,x13,y31,x21,y12] ;

de = (E/(1-nu*nu))*[ 1, nu, 0;
                    nu, 1, 0;
                    0, 0, (1-nu)/2 ];

dbe = de*be ;

ke = Ae*be'*de*be;

end
